@@ -1,4 +1,4 @@
- # Copyright (C) 2009, 2010 Oscar Perpiñán Lamigueiro
+ # Copyright (C) 2010, 2009 Oscar Perpiñán Lamigueiro
  #
  # This program is free software; you can redistribute it and/or
  # modify it under the terms of the GNU General Public License
@@ -20,12 +20,12 @@ fBTd<-function(mode='prom',
                    end=paste('31-12-',year,sep=''), 
                    format='%d-%m-%Y'){##,
 ##                   dates.bd, format.bd='%d-%m-%Y'){
-  promDays<-c(17,14,15,15,15,10,18,18,18,19,18,13);
+  promDays<-c(17,14,15,15,15,10,18,18,18,19,18,13)
   dates=switch(mode,
   ##  bd=as.POSIXct(dates.bd, tz='UTC', format=format.bd),
     serie={
-      start.<-as.POSIXct(start, format=format, tz='UTC');
-      end.<-as.POSIXct(end, format=format, tz='UTC');
+      start.<-as.POSIXct(start, format=format, tz='UTC')
+      end.<-as.POSIXct(end, format=format, tz='UTC')
       res<-seq(start., end., by="1 day")
     },
     prom=as.POSIXct(paste(year, 1:12, promDays, sep='-'), tz='UTC')
